@@ -9,10 +9,11 @@ from .exceptions import (  # noqa: F401
     RigelfileNotFoundError,
     UnformattedRigelfileError,
     UnknownROSPackagesError,
-    UnsupportedCompilerError
+    UnsupportedCompilerError,
+    UnsupportedPlatformError
 )
 from . import files  # noqa: F401
 from . import models  # noqa: F401
 from . import plugins  # noqa: F401
 
-__version__ = '0.2.18'
+__version__ = '0.2.19'
