@@ -1,4 +1,9 @@
-from .docker import DockerfileSection, DockerSection, SSHKey  # noqa: F401
+from .docker import (  # noqa: F401
+    DockerfileSection,
+    DockerSection,
+    SSHKey,
+    SUPPORTED_PLATFORMS
+)
 from .plugin import PluginSection  # noqa: F401
 from .rigelfile import Rigelfile  # noqa: F401
 from .simulation import SimulationSection  # noqa: F401
